# -*- coding: utf-8 -*-
#
# Copyright 2014 Bernard Yue
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import unicode_literals

__doc__ = """
Hanzi Converter 繁簡轉換器 | 繁简转换器

This module provides functions converting chinese text between simplified and
traditional characters.  It returns unicode represnetation of the text.

Class HanziConv is the main entry point of the module, you can import the
class by doing:

    >>> from hanziconv import HanziConv
"""

import os
from .charmap import simplified_charmap, traditional_charmap


class HanziConv(object):
    """This class supports hanzi (漢字) convention between simplified and
    traditional format"""
    __traditional_charmap = traditional_charmap
    __simplified_charmap = simplified_charmap

    @classmethod
    def __convert(cls, text, toTraditional=True):
        """Convert `text` to Traditional characters if `toTraditional` is
        True, else convert to simplified characters

        :param text:           data to convert
        :param toTraditional:  True -- convert to traditional text
                               False -- covert to simplified text
        :returns:              converted 'text`
        """
        if isinstance(text, bytes):
            text = text.decode('utf-8')

        fromMap = cls.__simplified_charmap
        toMap = cls.__traditional_charmap
        if not toTraditional:
            fromMap = cls.__traditional_charmap
            toMap = cls.__simplified_charmap

        final = ''
        for c in text:
            index = fromMap.find(c)
            if index != -1:
                final += toMap[index]
            else:
                final += c
        return final

    @classmethod
    def toSimplified(cls, text):
        """Convert `text` to simplified character string.  Assuming text is
        traditional character string

        :param text:  text to convert
        :returns:     converted UTF-8 characters

        >>> from hanziconv import HanziConv
        >>> print(HanziConv.toSimplified('繁簡轉換器'))
        繁简转换器
        """
        return cls.__convert(text, toTraditional=False)

    @classmethod
    def toTraditional(cls, text):
        """Convert `text` to traditional character string.  Assuming text is
        simplified character string

        :param text:  text to convert
        :returns:     converted UTF-8 characters

        >>> from hanziconv import HanziConv
        >>> print(HanziConv.toTraditional('繁简转换器'))
        繁簡轉換器
        """
        return cls.__convert(text, toTraditional=True)

    @classmethod
    def same(cls, text1, text2):
        """Return True if text1 and text2 meant literally the same, False
        otherwise

        :param text1: string to compare to ``text2``
        :param text2: string to compare to ``text1``
        :returns:     **True**  -- ``text1`` and ``text2`` are the same in meaning,
                      **False** -- otherwise

        >>> from hanziconv import HanziConv
        >>> print(HanziConv.same('繁简转换器', '繁簡轉換器'))
        True
        """
        t1 = cls.toSimplified(text1)
        t2 = cls.toSimplified(text2)
        return t1 == t2


del traditional_charmap, simplified_charmap



from __future__ import unicode_literals, absolute_import
# -*- coding: utf-8 -*-
#
# Copyright 2014 Bernard Yue
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .hanziconv import HanziConv

__version__ = '0.2.2'
__author__ = 'Bernard Yue'
__doc__ = """
This module converts between simplified and traditional Chinese Characters.
It consists of two parts:

      - a command line tool: ``hanzi-convert``
      - a python library: ``hanziconv``

**Command Line Tool Usage:**

.. code-block:: sh

    $ ./hanzi-convert --help
    usage: hanzi-convert [-h] [-o OUTFILE] [-s] [-v] infile

    Simplified and Traditional Chinese Character Conversion
    Version {} (By {})

    Converting to Traditional Hanzi by default with no -s flag

    positional arguments:
      infile                filename | "-", corresponds to stdin

    optional arguments:
      -h, --help            show this help message and exit
      -o OUTFILE, --output OUTFILE
                            filename to save output, stdout if omitted
      -s, --simplified      convert to simplified characters
      -v, --version         show program's version number and exit

**Python Library Example:**

    >>> from hanziconv import HanziConv
    >>> print(HanziConv.toSimplified('繁簡轉換器'))
    繁简转换器
    >>> print(HanziConv.toTraditional('繁简转换器'))
    繁簡轉換器
    >>> HanziConv.same('繁簡轉換器', '繁简转换器')
    True


""".format(__version__, __author__)

__all__ = ["HanziConv"]



# -*- coding: utf-8 -*-
#
# Copyright 2014 Bernard Yue
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import unicode_literals

import textwrap
from collections import defaultdict

s2t_exceptions = defaultdict(list)

masterlist = (
    ('只',
     """
        只有 只欠 只可 只說 只是 只要 只能 只好 只不 只得
        只怕 只恐 只顾 只管 只身 只限 只读 只争 只可
     """,
     """
     """),
    ('志',
     """
        志愿 志向 志同 志工 志气 志氣 志趣 志丹 志在 志士
        志留 志贺 志留 志不 志得 志高
     """,
     """
        立志 同志
     """),
    ('后',
     """天后 皇后 后里 太后 帝后
     """,
     """后羿
     """),
    ('面',
     """
        面积 面前 面对 面临 面试 面膜 面料 面向 面板 面子
        面部 面孔 面的 面貌 面霜 面具 面容 面世 面纱 面影
        面目 面色 面谈 面值 面相 面带 面罩 面皮 面颊 面市
        面授 面庞 面面 面目 面面 面额 面红 面壁 面熟 面巾
        面型 面儿 面镜 面黄 面临 面形 面首 面朝 面授 面对
        面貼
     """,
     """
        上面 下面 左面 右面 前面 後面 里面 外面 斜面 表面
        板面 镜面 水面 出面 对面 貼面
     """),
)
for key, data1, data2 in masterlist:
    for data in data1, data2:
        for d in textwrap.dedent(data).strip().split(' '):
            s2t_exceptions[key].append(d)




#!/usr/bin/env python
from __future__ import absolute_import, unicode_literals
import sys
import codecs

from hanziconv import __version__, __author__
from distutils.core import setup, Command

_classifiers = '''
        Development Status :: 4 - Beta
        Environment :: Console
        Environment :: Web Environment
        Intended Audience :: End Users/Desktop
        Intended Audience :: Developers
        Intended Audience :: System Administrators
        License :: OSI Approved :: Apache Software License
        Natural Language :: Chinese (Simplified)
        Natural Language :: Chinese (Traditional)
        Operating System :: OS Independent
        Operating System :: MacOS
        Operating System :: Microsoft :: Windows
        Operating System :: POSIX
        Programming Language :: Python
        Programming Language :: Python :: 2
        Programming Language :: Python :: 2.7
        Programming Language :: Python :: 3
        Programming Language :: Python :: 3.2
        Programming Language :: Python :: 3.3
        Programming Language :: Python :: 3.4
        Programming Language :: Python :: Implementation :: CPython
        Programming Language :: Python :: Implementation :: PyPy
        Topic :: System
        Topic :: Text Processing
        Topic :: Utilities
        '''
_classifiers = [s.strip() for s in _classifiers.splitlines() if s.strip()]

filename = 'README.rst'
encoding = 'utf-8'
if sys.version >= '3':
    with open(filename, 'r', encoding=encoding) as fh:
        docstring = fh.read()
    packages = ['hanziconv']
else:
    with open(filename, 'rU') as fh:
        fh = codecs.getreader(encoding)(fh)
        docstring = fh.read()
    packages = [b'hanziconv']


class PyTest(Command):
    """This class implement `python setup.py test` support for pytest"""
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import sys
        import subprocess
        errno = subprocess.call([sys.executable, 'runtests.py'])
        raise SystemExit(errno)


setup(name='hanziconv',
        version=__version__,
        description='Hanzi Converter for Traditional and Simplified Chinese',
        long_description=docstring,
        author=__author__,
        author_email='hanzi.converter@gmail.com',
        url='https://github.com/berniey/hanziconv',
        packages=packages,
        scripts=['hanzi-convert', ],
        cmdclass=dict(test=PyTest),
        classifiers=_classifiers,
        license='Apache 2.0',)
